from cyberonix.main.tools import *
import os
import inspect
def exit_program():
        os.system("clear")
        banner.main()
        print("\033[38;5;105m","[+] Thanks visit again".title())
def main():
    if inspect.stack()[1].function != "main":
        if not main.called:
              main.called=True
              start()
    else:
        start()

def start():
    while True:
        os.system("clear")
        banner.main()
        banner.attack("TOOLS")
        # import information_gathering

        list_attacks=["Information Gathering","Vulnerability Analysis","Web Application Analysis","Password Attacks","Wireless Attacks","Exploitation Tools","Sniffing and Spoofing","Post Exploitation","Pentesting and Bug-Bounty","go back"]
        #for output with index
        for i in range(len(list_attacks)):
                print(colors.options,f"{i}) {list_attacks[i]}".title(),colors.reset)
        try:
            option = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
        except KeyboardInterrupt:
            template.exit_program()
        if option == "0":
            print("\n[+] Information Gathering Section")
            os.system("clear")
            information_gathering.main()
        elif option == "1":
            print("\n[+] Vulnerability Analysis")
            os.system("clear")
            Vulnerability_Analysis.main()
        elif option == "2":
            print("\n[+] Web Application Analysis")
            os.system("clear")
            WEB_Application_Analysis.main()
        elif option == "3":
            print("\n[+] Password Attacks")
            os.system("clear")
            Password_Hacking.main()
        elif option == "4":
            print("\n[+] Wireless Attacks")
            os.system("clear")
            Wireless_Hacking.main()
        elif option == "5":
            print("\n[+] Exploitation Tools")
            os.system("clear")
            Exploitation_Tools.main()
        elif option == "6":
            print("\n[+] Sniffing and Spoofing")
            os.system("clear")
            Sniffing_and_Spoofing.main()
        elif option == "7":
            print("\n[+] Post Exploitation")
            os.system("clear")
            PostExploitationAttacks.main()
        elif option == "8":
            print("\n[+] Pentesting and Bug-Bounty")
            os.system("clear")
            Pentesting_Bug_Bounty.main()
        else:
            exit_program()
            return
main.called=False

if __name__ == "__main__": 
    main()



from cyberonix.main.tools import (
    banner,
    colors,
    information_gathering,template
)
from cyberonix.main.tools import (
    Configuration_Management,
    Secure_Transmission,
    Authentication,
    Session_Management,
    Authorization,
    data_validation,
    Cryptography,
    File_Upload,
    RiskyFuncPayment,
    html5,
    dos
)
import os
import requests
from bs4 import BeautifulSoup


# main function
def main():
    while True:
        os.system("clear")
        banner.main()
        banner.attack("Pentesting and Bug Bounty")
        list_attacks = [
            "Information Gathering",
            "Configuration Management",
            "Secure Transmission",
            "Authentication",
            "Session Management",
            "Authorization",
            "Data Validation",
            "Denial of Service",
            "Business Logic",
            "Cryptography",
            "Risky Functionality - File Uploads",
            "Risky Functionality - Card Payment",
            "HTML 5",
            "Go Back",
        ]
        for i in range(len(list_attacks)):
            print(colors.options, f"{i}) {list_attacks[i]}".title(), colors.reset)
        try:
            option = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
        except KeyboardInterrupt:
            template.exit_program()
        if option == "0":
            print("\n[+] Information Gathering")
            os.system("clear")
            information_gathering.main()
        elif option == "1":
            print("\n[+] Configuration Management")
            os.system("clear")
            Configuration_Management.main()
        elif option == "2":
            print("\n[+] Secure Transmission")
            os.system("clear")
            Secure_Transmission.main()
        elif option == "3":
            print("\n[+] Authentication")
            os.system("clear")
            Authentication.main()
        elif option == "4":
            print("\n[+] Session Management")
            os.system("clear")
            Session_Management.main()
        elif option == "5":
            print("\n[+] Authorization")
            os.system("clear")
            Authorization.main()
        elif option == "6":
            print("\n[+] Data Validation")
            os.system("clear")
            data_validation.main()
        elif option == "7":
            print("\n[+] Denial of Service")
            os.system("clear")
            dos.main()
        elif option == "8":
            print("\n[+] Business Logic")
            os.system("clear")
            template.template("Business Logic","no-tools",'Business logic is the custom rules or algorithms that handle the exchange of information between a database and user interface. Business logic is essentially the part of a computer program that contains the information (in the form of business rules) that defines or constrains how a business operates. Such business rules are operational policies that are usually expressed in true or false binaries. Business logic can be seen in the workflows that they support, such as in sequences or steps that specify in detail the proper flow of information or data, and therefore decision-making. Business logic is also known as "domain logic."',{"Business Logic":"https://portswigger.net/web-security/logic-flaws/examples#top","Exploiting Business Logic Vulnerabilities":"https://medium.com/armourinfosec/exploiting-business-logic-vulnerabilities-234f97d6c4c0","WEB APPLICATION — BUSINESS LOGIC VULNERABILITIES":"https://infosecwriteups.com/web-application-business-logic-vulnerabilities-51be9c6b99fa","Business Logic Flaw":"https://www.wallarm.com/what/business-logic-flaw"})
        elif option == "9":
            print("\n[+] Cryptography")
            os.system("clear")
            Cryptography.main()
        elif option == "10":
            print("\n[+] Risky Functionality - File Uploads")
            os.system("clear")
            File_Upload.main()
        elif option == "11":
            print("\n[+] Risky Functionality - Card Payment")
            os.system("clear")
            RiskyFuncPayment.main()
        elif option == "12":
            print("\n[+] HTML 5")
            os.system("clear")
            html5.main()
        else:
            return


def github_getting_text(link, selector, indexvalue):
    print("Please Wait....\r", end="")
    URL = link
    try:
        r = requests.get(URL)
        soup = BeautifulSoup(r.content, "html.parser")
        paras = soup.select(selector)
        # check index value from test file
        return paras[indexvalue].text
    except:
        return f"{colors.red}Not Loaded Because No Internet Connection{colors.reset}"


if __name__ == "__main__":
    main()



#!/usr/bin/python3
import os
import requests
from cyberonix.main.tools import banner,colors,template
from bs4 import BeautifulSoup

def main():
    while True:
        os.system("clear")
        banner.main()
        banner.attack("Vulnerability Analysis")
        list_attacks=["Wpscan","Wireshark","Wapiti","Nmap","Legion","Nikto","go back"]
        for i in range(len(list_attacks)):
                print(colors.options,f"{i}) {list_attacks[i]}".title(),colors.reset)
        try:
            option = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
        except KeyboardInterrupt:
            template.exit_program()
        if option=="0":
            print("\n[+] Wpscan")
            os.system("clear")
            github = "WPScan is a security scanner designed for testing the security of websites built using WordPress. WPScan was developed using the Ruby programming language and then released in the first version in 2019. The WPScan security scanner is primarily intended to be used by WordPress administrators and security teams to assess the security status of their WordPress installations. It is used to scan WordPress websites for known vulnerabilities both in WordPress and commonly used WordPress plugins and themes. The code base for WPScan is licensed under GPLv3"
            template.template("wpscan","wpscan -h",github.strip(),{'WPScan Intro: How to Scan for WordPress Vulnerabilities':'https://blog.sucuri.net/2021/05/wpscan-how-to-scan-for-wordpress-vulnerabilities.html/','WPScan:WordPress Pentesting Framework':'https://www.hackingarticles.in/wpscanwordpress-pentesting-framework/','How To Use WPScan to Test for Vulnerable Plugins and Themes in Wordpress':"https://www.digitalocean.com/community/tutorials/how-to-use-wpscan-to-test-for-vulnerable-plugins-and-themes-in-wordpress","How to Use wpscan tool in Kali Linux":"https://www.geeksforgeeks.org/how-to-use-wpscan-tool-in-kali-linux/","WPScan Usage Example [Enumeration + Exploit]":"https://www.cyberpunk.rs/wpscan-usage-example"})
        elif option=="1":
            print("\n[+] Wireshark")
            os.system("clear")
            github=github_getting_text("https://github.com/wireshark/wireshark",'p[dir="auto"]',0)
            template.template("wireshark","wireshark",github.strip(),{'How To Install & Use Wireshark On Kali Linux':'https://infosecscout.com/wireshark-on-kali-linux/','Wireshark Tool Documentation':'https://www.kali.org/tools/wireshark/','Wireshark Training':'https://www.wireshark.org/docs/','Wireshark – Resources':'https://blog.inf.ed.ac.uk/atate/2023/01/14/wireshark-resources/','Kerberos Wireshark Captures: A Windows Login Example':'https://medium.com/@robert.broeckelmann/kerberos-wireshark-captures-a-windows-login-example-151fabf3375a','Wireshark – Packet Capturing and Analyzing':'https://www.geeksforgeeks.org/wireshark-packet-capturing-and-analyzing/','https://unit42.paloaltonetworks.com/wireshark-tutorial-decrypting-https-traffic/':'https://unit42.paloaltonetworks.com/wireshark-tutorial-decrypting-https-traffic/'})
        elif option=="2":
            print("\n[+] Wapiti")
            os.system("clear")
            github=github_getting_text("https://github.com/wapiti-scanner/wapiti",'p[dir="auto"]',6)
            template.template("wapiti","wapiti",github.strip(),{"wapiti free web application vulnerability scanner":"https://pentestit.medium.com/wapiti-free-web-application-vulnerability-scanner-ce7712adf644","Official docs":"https://github.com/wapiti-scanner/wapiti","wapiti tutorial":"https://www.kalilinux.in/2021/01/wapiti-tutorial.html","complete guide to using wapiti web vulnerability scanner to keep your web applications websites secure":"https://linuxsecurity.com/features/complete-guide-to-using-wapiti-web-vulnerability-scanner-to-keep-your-web-applications-websites-secure"})
        elif option=="3":
            print("\n[+] Nmap")
            os.system("clear")
            github = "Nmap (Network Mapper) is a network scanner created by Gordon Lyon (also known by his pseudonym Fyodor Vaskovich). Nmap is used to discover hosts and services on a computer network by sending packets and analyzing the responses."
            template.template("nmap","nmap -h",github.strip(),{"Nmap Cheat-Sheet":"https://www.stationx.net/nmap-cheat-sheet/","Official website":"https://nmap.org/ ","Other resources":"https://linux.die.net/man/1/nmap"})            
        elif option=="4":
            print("\n[+] Legion")
            os.system("clear")
            github=github_getting_text("https://github.com/GoVanguard/legion",'p[class="f4 my-3"]',0)
            template.template("legion","legion",github.strip(),{'Legion Tool in Kali Linux':'https://www.geeksforgeeks.org/legion-tool-in-kali-linux','Legion -- Test Web Application Vulnerability Automatically':'https://www.kalilinux.in/2020/09/legion-kali-linux.html','How to use Legion application in Kali Linux | Information Gathering':'https://www.youtube.com/watch?v=5UAfXbP5Y0k'})
        elif option=="5":
            print("\n[+] Nikto")
            os.system("clear")
            github=github_getting_text("https://en.wikipedia.org/wiki/Nikto_(vulnerability_scanner)",'p',1)
            template.template("nikto","nikto -h",github.strip(),{'What is Nikto and it’s usages ?':'https://www.geeksforgeeks.org/what-is-nikto-and-its-usages/','Nikto: A Practical Website Vulnerability Scanner':'https://securitytrails.com/blog/nikto-website-vulnerability-scanner','Nikto Official Docs':'https://github.com/sullo/nikto/wiki'})
        else:
            return

def github_getting_text(link,selector,indexvalue):
    print("Please Wait....\r",end="")
    URL = link
    try:
        r = requests.get(URL)
        soup = BeautifulSoup(r.content, 'html.parser')
        paras = soup.select(selector)
        #check index value from test file
        return paras[indexvalue].text
    except:
        return f"{colors.red}NotLloaded Because No Internet Connection{colors.reset}"

def tool_writeups():
    print(f"{colors.options}1) TOOL(About,Installation)")
    print(f"2) Write Ups")
    print(f"3) Go Back..")
    try:
        ask=input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
    except KeyboardInterrupt:
        template.exit_program()
    return ask

if __name__=='__main__':
    main()



from cyberonix.main.tools import banner, template, colors, writeup
from cyberonix.main import Cheat_sheet
import os
import requests
from bs4 import BeautifulSoup


def main():
    while True:
        os.system("clear")
        banner.main()
        banner.attack(f"File Upload")
        list_attacks = ["Tools", "Writeups", "Go Back"]
        for i in range(len(list_attacks)):
            print(colors.options, f"{i+1}) {list_attacks[i]}".title(), colors.reset)
        try:
            option = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
        except KeyboardInterrupt:
            template.exit_program()
        if option == "1":
            while True:
                os.system("clear")
                banner.main()
                banner.attack(f"Tools")
                list_tools = ["fuxploider", "Upload Scanner", "go back"]
                for i in range(len(list_tools)):
                    print(
                        colors.options, f"{i+1}) {list_tools[i]}".title(), colors.reset
                    )
                try:
                    option = input(f"\n {colors.select}Select an Option ->{colors.reset} ")
                except KeyboardInterrupt:
                    template.exit_program()
                if option == "1":
                    github = github_getting_text(
                        "https://github.com/almandin/fuxploider", 'p[dir="auto"]', 1
                    )
                    template.template(
                        "flxploider",
                        "python3 fuxploider.py -h",
                        github,
                        "no-writeups",
                        link="https://github.com/almandin/fuxploider.git",
                        method="github",
                        github_install="git clone https://github.com/almandin/fuxploider.git && python3 -m pip install -r fuxploider/requirements.txt ",
                        github_check="fuxploider"
                    )
                elif option == "2":
                    github = github_getting_text(
                        "https://github.com/portswigger/upload-scanner", "p[dir=auto]", 0
                    )
                    template.template(
                        "Upload Scanner",
                        "https://github.com/portswigger/upload-scanner",
                        github,
                        "no-writeups",
                        method="browser"
                    )

                else:
                    break
        elif option == "2":
            # writeup.writeup({"Test Upload of Unexpected File Types":"https://owasp.org/www-project-web-security-testing-guide/latest/4-Web_Application_Security_Testing/10-Business_Logic_Testing/08-Test_Upload_of_Unexpected_File_Types","What is Unrestricted File Upload?":"https://www.aptive.co.uk/blog/unrestricted-file-upload-testing/","File Upload General Methodology":"https://book.hacktricks.xyz/pentesting-web/file-upload","File upload vulnerabilities":"https://portswigger.net/web-security/file-upload","File Upload Attacks (Part 2)":"https://blog.yeswehack.com/yeswerhackers/file-upload-attacks-part-2/","Hunting for Bugs in File Upload Feature:":"https://sm4rty.medium.com/hunting-for-bugs-in-file-upload-feature-c3b364fb01ba","How I abused the file upload function to get a high severity vulnerability in Bug Bounty":"https://infosecwriteups.com/how-i-abused-the-file-upload-function-to-get-a-high-severity-vulnerability-in-bug-bounty-7cdcf349080b","Directory Traversal via PHP Multi-File Uploads":"https://nealpoole.com/blog/tag/file-upload/"},"Writups")
            writeup.writeup(
                {
                    "Test Upload of Unexpected File Types": "https://owasp.org/www-project-web-security-testing-guide/latest/4-Web_Application_Security_Testing/10-Business_Logic_Testing/08-Test_Upload_of_Unexpected_File_Types",
                    "What is Unrestricted File Upload?": "https://www.aptive.co.uk/blog/unrestricted-file-upload-testing/",
                    "File Upload General Methodology": "https://book.hacktricks.xyz/pentesting-web/file-upload",
                    "File upload vulnerabilities": "https://portswigger.net/web-security/file-upload",
                    "File Upload Attacks (Part 2)": "https://blog.yeswehack.com/yeswerhackers/file-upload-attacks-part-2/",
                    "Hunting for Bugs in File Upload Feature:": "https://sm4rty.medium.com/hunting-for-bugs-in-file-upload-feature-c3b364fb01ba",
                    "How I abused the file upload function to get a high severity vulnerability in Bug Bounty": "https://infosecwriteups.com/how-i-abused-the-file-upload-function-to-get-a-high-severity-vulnerability-in-bug-bounty-7cdcf349080b",
                    "Directory Traversal via PHP Multi-File Uploads": "https://nealpoole.com/blog/tag/file-upload/",
                },
                "File Upload writups",
            )

        else:
            return


def github_getting_text(link, selector, indexvalue):
    print(f"Please Wait....\r", end="")
    URL = link
    try:
        r = requests.get(URL)
        soup = BeautifulSoup(r.content, "html.parser")
        paras = soup.select(selector)
        # check index value from test file
        return paras[indexvalue].text
    except:
        return f"{colors.red}NotLloaded Because No Internet Connection{colors.reset}"


if __name__ == "__main__":
    main()




from cyberonix.main.tools import banner,colors,template
import os
import requests
from bs4 import BeautifulSoup

#main function
def main():
    while True:
        os.system("clear")
        banner.main()
        banner.attack("Sniffing & Spoofing")
        list_attacks=[" Wireshark"," Bettercap"," Tcpdump"," Arpspoof"," Dsniff"," Scapy"," Netsniff-ng"," Macchanger"," Responder"," Airgeddon","Sharesniffer","Wifi-Pumpkin-3","Go Back"]
        for i in range(len(list_attacks)):
                print(colors.options,f"{i}) {list_attacks[i]}".title(),colors.reset)
        try:
            option = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
        except KeyboardInterrupt:
            template.exit_program()
        if option=="0":
            print("\n[+] Wireshark")
            os.system("clear")
            # name,command,discription,writeup,link=True,method="kali",github_install="",github_check=True
            github = "Wireshark is a free and open-source packet analyzer. It is used for network troubleshooting, analysis, software and communications protocol development, and education. It can be used to examine data from a live network or from a previously saved capture file. Wireshark provides a graphical user interface (GUI) for capturing and analyzing network traffic."
            template.template("wireshark","wireshark",github.strip(),{"Wireshark Cheat-Sheet":"https://www.comparitech.com/net-admin/wireshark-cheat-sheet","What-is-Wireshark-and-How-to-Use-it":"https://www.comptia.org/content/articles/what-is-wireshark-and-how-to-use-it ","Video Resource Wireshark":"https://www.youtube.com/playlist?list=PLBf0hzazHTGPgyxeEj_9LBHiqjtNEjsgt"})        
        elif option=="1":
            print("\n[+] Bettercap")
            os.system("clear")
            github=github_getting_text("https://github.com/bettercap/bettercap",'p[dir="auto"]',3)
            template.template("bettercap","bettercap",github.strip(),{"Man in the Middle": "https://www.cybervie.com/blog/easy-and-better-man-in-the-middle-using-bettercap/", "MITM Labs Write-up": "https://charlesreid1.com/wiki/MITM_Labs/Bettercap_Over_Wifi", "NTLM Capturing": "https://blog.xpnsec.com/bettercap-capturing-ntlm/", "DNS Spoofing": "https://psychovik.medium.com/dns-spoofing-using-bettercap-24a8435f7a03"})
        elif option=="2":
            print("\n[+] Tcpdump")
            os.system("clear")
            github = github_getting_text("https://opensource.com/article/18/10/introduction-tcpdump",'p',5)
            template.template("tcpdump","tcpdump -h",github.strip()+'\r\n - '.join(github.strip().split('\n')),{"TCPDump": "https://www.qnx.com/developers/docs/7.0.0/index.html#com.qnx.doc.neutrino.utilities/topic/t/tcpdump.html","Deep Packet Analysis": "https://thwack.solarwinds.com/resources/b/geek-speak/posts/deep-packet-analysis---practical-applications-with-tcpdump","TCPDump F5": "https://support.f5.com/csp/article/K2289","TCPDump FreeBSD": "https://www.freebsd.org/cgi/man.cgi?tcpdump"})
        elif option=="3":
            print("\n[+] Arpspoof")
            os.system("clear")
            github = "arpspoof is a utility for network auditing and penetration testing. It is part of the dsniff suite of tools, which is used to perform various types of network attacks and security auditing. It can be used to intercept and modify traffic on a local area network. It works by sending out specially crafted ARP (Address Resolution Protocol) packets, which can be used to redirect traffic from one host to another. This is known as ARP spoofing or ARP cache poisoning."
            template.template("dsniff","arpspoof",github.strip(),{"Arp_Spoofing_Using_Man_In_The_Middle_Attack":"https://linuxhint.com/arp_spoofing_using_man_in_the_middle_attack/","ArpSpoof Video Resource":"https://www.youtube.com/watch?v=8SIP36Fym7U"})
        elif option=="4":
            print("\n[+] Dsniff")
            os.system("clear")
            github = "dsniff is a collection of tools for network auditing and penetration testing. dsniff, filesnarf, mailsnarf, msgsnarf, urlsnarf, and webspy passively monitor a network for interesting data (passwords, e-mail, files, etc.). arpspoof, dnsspoof, and macof facilitate the interception of network traffic normally unavailable to an attacker (e.g, due to layer-2 switching). sshmitm and webmitm implement active monkey-in-the-middle attacks against redirected SSH and HTTPS sessions by exploiting weak bindings in ad-hoc PKI."
            template.template("dsniff","dsniff -h",github.strip(),{"Dsniff Repo": "https://github.com/tecknicaltom/dsniff","Manpages Dsniff": "https://kaisenlinux.org/manpages/dsniff.html","Introduction": "http://www.ouah.org/dsniffintr.htm"})
        elif option=="5":
            print("\n[+] Scapy")
            os.system("clear")
            github="Scapy is a Python program that enables the user to send, sniff and dissect and forge network packets. This capability allows construction of tools that can probe, scan or attack networks."
            template.template("scapy","chmod +x run_scapy && ./run_scapy",github.strip(),{"what is Scapy": "https://santandergto.com/en/guide-using-scapy-with-python/#whatisScapy","Scapy Introduction": "https://scapy.readthedocs.io/en/latest/introduction.html","Scapy Usage": "https://python.astrotech.io/network/transport/scapy.html","Scapy Tutorial": "https://youtu.be/LvaII2PEwcQ"},method="github",github_install="git clone https://github.com/secdev/scapy.git",github_check="scapy")
        elif option=="6":
            print("\n[+] Netsniff-ng")
            os.system("clear")
            github_text_0=github_getting_text("http://netsniff-ng.org/",'p',0)
            github_text_1=github_getting_text("http://netsniff-ng.org/",'p',1)
            github_text_2=github_getting_text("http://netsniff-ng.org/",'p',2)
            github = github_text_0 + github_text_1 + github_text_2
            template.template("netsniff-ng","netsniff-ng -h",github.strip(),{"Netsniff-ng Website": "http://netsniff-ng.org/", "Sniffing Network Traffic": "https://medium.com/purple-team/sniffing-network-traffic-with-netsniff-ng-55b8f5d436c2", "Manual": "https://linux.die.net/man/8/netsniff-ng", "Video Resources": "https://www.irongeek.com/i.php?page=videos/hack3rcon4/09-netsniff-ng-jon-schipp"})
        elif option=="7":
            print("\n[+] Macchanger")
            os.system("clear")
            github=github_getting_text("https://www.kali.org/tools/macchanger/",'p',0)
            template.template("macchanger","macchanger --help",github.strip(),{"How to Change Mac Address": "https://linuxconfig.org/how-to-change-mac-address-using-macchanger-on-kali-linux/", "Macchanger on Kali Linux": "https://kennyvn.com/change-mac-address-macchanger-kali-linux/", "Permanently Change Mac Address": "https://www.linuxuprising.com/2018/05/how-to-permanently-change-mac-address.html"})
        elif option=="8":
            print("\n[+] Responder")
            os.system("clear")
            github_text_0=github_getting_text("https://www.kali.org/tools/responder/",'p',1)
            github_text_1=github_getting_text("https://www.kali.org/tools/responder/",'p',2)
            github = github_text_0 + github_text_1
            template.template("responder","responder -h",github,{"Responder-Guide": "https://www.ivoidwarranties.tech/posts/pentesting-tuts/responder/guide/","How-To-Use-Responder-to-Capture-NETNTLM-and-Grab-a-Shell": "https://www.a2secure.com/blog-en/how-to-use-responder-to-capture-netntlm-and-grab-a-shell/","infinitelogins.com-Responder": "https://infinitelogins.com/tag/responder/","Capture-Window-10-NTLM-Hashes-Responder": "https://secnhack.in/capture-window-10-ntlm-hashes-responder"})
        elif option=="9":
            print("\n[+] Airgeddon")
            os.system("clear")
            github = "Airgeddon is a wireless security auditing tool that is used to assess the security of wireless networks. It can be used to perform various types of attacks, such as cracking WPA/WPA2 passwords, capturing WPA/WPA2 handshakes, and identifying vulnerable wireless access points. The tool is open-source and runs on Linux systems. Airgeddon is not intended for illegal use, and should only be used on networks that you have permission to test."
            template.template("airgeddon","airgeddon",github.strip(),{"How to Use Airgeddon in Kali Linux":"https://www.systranbox.com/how-to-use-airgeddon-in-kali-linux/", "Airgeddon Wifi Crack in Kali Linux":"https://www.kalilinux.in/2021/03/airgeddon-wifi-crack-kalilinux.html", "Airgeddon Multi-Use Bash Script to Audit Wireless Networks":"https://xploitlab.com/airgeddon-multi-use-bash-script-to-audit-wireless-networks/", "Airgeddon Tool Installation and Fix All Errors":"https://www.hacknos.com/airgeddon-tool-installation-and-fix-all-errors/"})
        elif option=="10":
            print("\n[+] Sharesniffer")
            os.system("clear")
            github=github_getting_text("https://github.com/shirosaidev/sharesniffer",'p[dir="auto"]',2)
            template.template("sharesniffer","pip install python-nmap netifaces >/dev/null 2>&1 && chmod +x sharesniffer.py && ./sharesniffer.py -h",github.strip(),{"Sharesniffer Github-Repo":"github.com/shirosaidev/sharesniffer","Sharesniffer Presentation":"slideplayer.com/slide/6055181/"},method="github",github_install="git clone https://github.com/shirosaidev/sharesniffer",github_check="sharesniffer")    
        elif option=="11":
            print("\n[+] Wifi-Pumpkin-3")
            os.system("clear")
            github=github_getting_text("https://github.com/P0cL4bs/wifipumpkin3",'p[dir="auto"]',4)
            template.template("wifipumpkin3","wifipumpkin3",github.strip(),{"Wireless Penetration Testing": "https://www.hackingarticles.in/wireless-penetration-testing-wifipumpkin3/", "WiFiPumpkin3 : Powerful Framework For Rogue Access Point Attack": "https://kalilinuxtutorials.com/wifipumpkin3/"})    
        else:
            return
def github_getting_text(link,selector,indexvalue):
    print("Please Wait....\r",end="")
    URL = link
    try:
        r = requests.get(URL)
        soup = BeautifulSoup(r.content, 'html.parser')
        paras = soup.select(selector)
        #check index value from test file
        return paras[indexvalue].text
    except:
        return f"{colors.red}Not Loaded Because No Internet Connection{colors.reset}"

if __name__=='__main__':
    main()



#!/usr/bin/python3
import os
import subprocess
from cyberonix.main import *
from cyberonix.main.tools import colors, banner
import time, argparse


def exit_program():
    os.system("clear")
    banner.main()
    print("\033[38;5;105m", "[+] Thanks visit again".title())
    exit()


try:

    def starting():
        parser = argparse.ArgumentParser(
            description="Cyberonix is a complete resource hub for Cyber Security Community. Our aim is to make this tool an 1 stop solution for all the Hackers out there to get resources of various topics in Cyber Security. We will keep updating this tool & adding new & updated resources on the go.",
        )
        main_args = parser.add_argument_group('Main Arguments')
            
        main_args.add_argument(
            "--tools", "-t", action="store_true", help="Run Tools Function"
        )
        main_args.add_argument(
            "--cheatsheet", "-c", action="store_true", help="Run Cheatsheet Function"
        )
        main_args.add_argument(
            "--news",
            "-n",
            nargs="?",
            metavar="Date",
            const="latest",
            type=str,
            help="Date In The Format yyyy-mm-dd",
        )
        ip_args = parser.add_argument_group('IP')
        ip_args.add_argument(
            "--getip", "-gip", help="Get Ip Of A Domain(options: --file,--domain,--output)", action="store_true",
        )
        ip_args.add_argument("--ipinfo", "-ipi", action="store_true", help="Get IP Infomation(Options: --ip,--file,--output)")
                      
        dns_Args = parser.add_argument_group('DNS Records')
        parser.add_argument("--domain", "-D", dest='domain',
                    help='Specify the domain', option_strings=['--domain'])
        dns_Args.add_argument(
            "--dnsrecord", "-dns", action="store_true", help="To Get DNS Records(options: --domain,--file,--output) and use --record to specify record name"
        )
        dns_Args.add_argument(
            "--record", "-r", help="To Give Record For DNSrecord(Like: A,TXT,MX)"
        )
        screenshot_Args = parser.add_argument_group('Screenshoting')
        screenshot_Args.add_argument(
            "--screenshot",
            "-s",
            action="store_true",
            help="To Get Screenshot Of Websites(options: --file,--domain,--output)",
        )
        parser.add_argument("--output", "-o", help="Specify An Output File (-o path/to/location)")
        parser.add_argument("--file", "-f", help="Specify An Input File (-f path/to/file.txt)")
        
        asn_Args = parser.add_argument_group('ASN Record')
        parser.add_argument("--ip", "-ip", help="Specify IP Address")
        asn_Args.add_argument(
                "--asnrecord", "-asn", action="store_true", help="To Get ASN Record(Options: --ip,--file,--output)"
        )
        password_Args = parser.add_argument_group("Password Generation")
        password_Args.add_argument(
            "--passwordgen", "-P", action="store_true", help="To Generate Password"
        )
        password_Args.add_argument(
            "--default-password-gen",
            "-pass",
            action="store_true",
            help="To Generate Random Password (Recommended)(You can only use --length,--checkpassword)",
        )

        password_Args.add_argument(
            "--upper", "-u", action="store_true", help="For Uppercase"
        )
        password_Args.add_argument(
            "--lower", "-l", action="store_true", help="For Lowercase"
        )
        password_Args.add_argument(
            "--digits", "-d", action="store_true", help="For Digits"
        )
        password_Args.add_argument(
            "--punctuation", "-p", action="store_true", help="For Punctuation"
        )
        password_Args.add_argument(
            "--length", "-L", help="To Specify Length Of Password (Default=8)"
        )
        password_Args.add_argument(
            "--checkpassword",
            "-C",
            action="store_true",
            help="To Check Your Generated Password",
        )
        
        hstatus_Args = parser.add_argument_group('HTTP Status')
        hstatus_Args.add_argument(
            "--http-status",
            "-S",
            action="store_true",
            help="To Get Http Status Code Of A Domain(Options: --domain,--file,--output)",
        )
        remove_dub_Args = parser.add_argument_group('remove duplicate')
        remove_dub_Args.add_argument(
            "--remove-duplicate",
            "-rd",
            action="store_true",
            help="To Remove Dublicates From a File(Options: --file,--output)",
        )
        args = parser.parse_args()

        if args.tools:
            tool.main()
        elif args.getip:
            if args.file:
                if args.output:
                    arguments.getip(path=args.file, output=args.output)
                else:
                    arguments.getip(path=args.file)
            elif args.domain:
                if args.output:
                    arguments.getip(url=args.domain, output=args.output)
                else:
                    arguments.getip(url=args.domain)
            else:
                print(
                    f"{colors.red}[!] Please file with --file path/to/file or pass a single domain with --domain https://example.com{colors.reset}"
                )

        elif args.cheatsheet:
            Cheat_sheet.main()
        elif args.news:
            if args.news == "latest" or args.news is None:
                news.main(args.news)
            else:
                news.main(args.news)
        elif args.cheatsheet:
            Cheat_sheet.main()
        elif args.screenshot:
            if args.file:
                if args.output:
                    arguments.screenshot(path=args.file,output=args.output)
                else:
                    arguments.screenshot(path=args.file)
            elif args.domain:
                if args.output:
                    arguments.screenshot(url=args.domain,output=args.output)
                else:
                    arguments.screenshot(url=args.domain)

            else:
                print(
                    f"{colors.red}[!] Please file with --file path/to/file or pass a single domain with --domain https://example.com{colors.reset}"
                )
        elif args.remove_duplicate:
            if args.file:
                if args.output:
                    arguments.remove_dublicates(location=args.file, output=args.output)
                else:
                    arguments.remove_dublicates(location=args.file)

            else:
                print(
                    f"{colors.red}[!] Please file with --file path/to/file or pass a single domain with --domain https://example.com{colors.reset}"
                )

        elif args.asnrecord:
            if args.file:
                if args.output:
                    arguments.asnrecord(path=args.file, output=args.output)
                else:
                    arguments.asnrecord(path=args.file)
            elif args.ip:
                if args.output:
                    arguments.asnrecord(url=args.ip, output=args.output)
                else:
                    arguments.asnrecord(url=args.ip)

            else:
                print(
                    f"{colors.red}[!] Please file with --file path/to/file or pass a single ip with --ip 8.8.8.8{colors.reset}"
                )

        elif args.http_status:
            if args.file:
                if args.output:
                    arguments.http_status_code(path=args.file, output=args.output)
                else:
                    arguments.http_status_code(path=args.file)
            elif args.domain:
                if args.output:
                    arguments.http_status_code(url=args.domain, output=args.output)
                else:
                    arguments.http_status_code(url=args.domain)
            else:
                print(
                    f"{colors.red}[!] Please file with --file path/to/file or pass a single domain with --domain https://example.com{colors.reset}"
                )
        elif args.ipinfo:
            if args.file:
                if args.output:
                    arguments.ipinformation(path=args.file, output=args.output)
                else:
                    arguments.ipinformation(path=args.file)
            elif args.ip:
                if args.output:
                    arguments.ipinformation(url=args.ip, output=args.output)
                else:
                    arguments.ipinformation(url=args.ip)
            else:
                print(
                    f"{colors.red}[!] Please file with --file path/to/file or pass a single ip with --ip 8.8.8.8{colors.reset}"
                )


        elif args.passwordgen:
            if args.length:
                arguments.password_gen(
                    args.upper,
                    args.lower,
                    args.digits,
                    args.punctuation,
                    args.length,
                    args.checkpassword,
                )
            else:
                arguments.password_gen(
                    args.upper,
                    args.lower,
                    args.digits,
                    args.punctuation,
                    check=args.checkpassword,
                )
        elif args.default_password_gen:
            if args.length:
                arguments.password_gen(length=args.length, check=args.checkpassword)
            else:
                arguments.password_gen(check=args.checkpassword)
        elif args.dnsrecord:
            if args.record:
                if args.file:
                    if args.output:
                        arguments.dnsrecords(path=args.file, names=args.record,output=args.output)
                    else:
                        arguments.dnsrecords(path=args.file, names=args.record)
                elif args.domain:
                    if args.output:
                        arguments.dnsrecords(url=args.domain, names=args.record,output=args.output)
                    else:
                        arguments.dnsrecords(url=args.domain, names=args.record)
                else:
                    print("please give --domain/--file also")
            elif args.domain:
                if args.record:
                    if args.output:
                        arguments.dnsrecords(url=args.domain, names=args.record,output=args.output)
                    else:
                        arguments.dnsrecords(url=args.domain, names=args.record)
                else:
                    print("please give --record also")
        else:
            main()

    def main():
        while True:
            os.system("clear")
            banner.main()
            list_attacks = ["TOOLS", "CHEATSHEET", "NEWS", "exit"]
            for i in range(len(list_attacks)):
                print(colors.options, f"{i}) {list_attacks[i]}".title(), colors.reset)
            try:
                option = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
            except KeyboardInterrupt:
                exit_program()
            if option == "0":
                os.system("clear")
                tool.main()
            elif option == "1":
                os.system("clear")
                Cheat_sheet.main()
            elif option == "2":
                os.system("clear")
                news.main()
            else:
                exit_program()

    # to run file separately
    if __name__ == "__main__":
        starting()
except KeyboardInterrupt:
    exit_program()
except Exception as err:
    os.system("clear")
    banner.main()
    banner.attack(f"{colors.red}ERROR{colors.reset}")
    banner.description(f"{colors.red}{err}{colors.reset}")



import threading
from bs4 import BeautifulSoup
from cyberonix.main.tools import banner, template, waiting, writeup, colors, run_on_browser
import os
import requests
from bs4 import BeautifulSoup


def main():
    while True:
        os.system("clear")
        banner.main()
        banner.attack("Data Validation Vulnerabilities")
        list_vulns = [
            "XSS",
            "XXE - XML",
            "HTML Injection",
            "SQL Injection",
            "Command Injection",
            "HTTP Smuggling",
            "HTTP Parameter Pollution",
            "Open Redirection",
            "LFI",
            "Go Back",
        ]
        for i in range(len(list_vulns)):
            print(colors.options, f"{i}) {list_vulns[i]}".title(), colors.reset)
        try:
            vulns = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
        except KeyboardInterrupt:
            template.exit_program()
        if vulns == "0":
            while True:
                os.system("clear")
                banner.main()
                banner.attack("XSS")
                # name,command,discription,writeups,link="",method="kali",github_install="",github_check=""
                ask = vuln_options()
                if ask == "1":
                    while True:
                        os.system("clear")
                        banner.main()
                        banner.attack("XSS")
                        des = "It is recommended to test manually for XSS vulnerability to get better understanding & results.\nCheck out the writeup section to to learn about Cross Site Scripting"
                        banner.description(des)
                        list_tools = ["Dalfox", "XSStrike", "Xsser", "go back"]
                        for i in range(len(list_tools)):
                            print(
                                colors.options,
                                f"{i}) {list_tools[i]}".title(),
                                colors.reset,
                            )
                        option = input(
                            f"\n {colors.select}Select an Option ->{colors.reset} "
                        )
                        if option == "0":
                            print("\n[+] Dalfox")
                            github = github_getting_text(
                                "https://github.com/hahwul/dalfox", 'p[dir="auto"]', 1
                            )
                            template.template(
                                "dalfox",
                                "dalfox -h",
                                github.strip(),
                                {
                                    "DalFox - Parameter Analysis and XSS Scanning tool": "https://www.geeksforgeeks.org/dalfox-parameter-analysis-and-xss-scanning-tool/",
                                    "Automating XSS using Dalfox, GF and Waybackurls": "https://infosecwriteups.com/automating-xss-using-dalfox-gf-and-waybackurls-bc6de16a5c75",
                                    "Dalfox - Hacker Tools: XSS Scanning Made Easy": "https://blog.intigriti.com/2021/09/14/hacker-tools-dalfox/",
                                    "Offensive Security Tool: Dalfox": "https://www.blackhatethicalhacking.com/tools/dalfox",
                                },
                                link="github.com/hahwul/dalfox/v2@latest",
                                method="go",
                            )
                        elif option == "1":
                            print("\n[+] XSStrike")
                            github = github_getting_text(
                                "https://github.com/s0md3v/XSStrike", "p[dir=auto]", 3
                            )
                            template.template(
                                "XSStrike",
                                "python3 xsstrike.py -h",
                                github.strip(),
                                {
                                    "XSStrike – Hunting for low-hanging fruits in Kali Linux": "https://www.geeksforgeeks.org/xsstrike-hunting-for-low-hanging-fruits-in-kali-linux/",
                                    "Hacker tools: XSStrike – Hunting for low-hanging fruits.": "https://blog.intigriti.com/2021/06/29/hacker-tools-xsstrike-hunting-for-low-hanging-fruits/",
                                    "XSS Tools - XSStrike": "https://book.hacktricks.xyz/pentesting-web/xss-cross-site-scripting/xss-tools",
                                    "XSStrike Usage Example (v3.x)": "https://www.cyberpunk.rs/xsstrike-usage-example-v3-x",
                                    "Advanced XSS Detection Suite – XSStrike": "https://www.cyberpunk.rs/advanced-xss-detection-suite-xsstrike",
                                },
                                link="https://github.com/s0md3v/XSStrike.git",
                                method="github",
                                github_install="git clone https://github.com/s0md3v/XSStrike.git",
                                github_check="XSStrike",
                            )
                        elif option == "2":
                            print("\n[+] Xsser")
                            github = github_getting_text(
                                "https://www.kali.org/tools/xsser/", "p", 3
                            )
                            template.template(
                                "xsser",
                                "xsser -h",
                                github.strip(),
                                {
                                    "Detecting and Exploiting XSS Injections using XSSer Tool": "https://securityxploded.com/detecting-exploiting-xss-using-xsser-tool.php",
                                    "XSSer - Detect and Exploit XSS vulnerabilities": "https://gbhackers.com/xsser-automated-framework-detectexploit-report-xss-vulnerabilities/",
                                    "XSSer- Cross Site Scripting Penetration Tool": "https://www.ehacking.net/2011/02/xsser-cross-site-scripting-penetration.html",
                                },
                            )

                        else:
                            # print(f"{colors.red}[-]Wrong Input{colors.reset}")
                            break
                elif ask == "2":
                    writeup.writeup(
                        {
                            "The popping history of XSS": "https://thexssrat.medium.com/the-popping-history-of-xss-4122e34ac586",
                            "Reflected Cross Site Scripting": "https://owasp.org/www-project-web-security-testing-guide/v41/4-Web_Application_Security_Testing/07-Input_Validation_Testing/01-Testing_for_Reflected_Cross_Site_Scripting",
                            "XXS HackerOne Report": "https://www.hacker101.com/sessions/xss",
                            "From P5 to P2, from nothing to 1000+$": "https://medium.com/@mohameddaher/from-p5-to-p5-to-p2-from-nothing-to-1000-bxss-4dd26bc30a82",
                            "Reflected XSS on Microsoft.com via Angular Js template injection": "https://infosecwriteups.com/reflected-xss-on-microsoft-com-via-angular-template-injection-2e26d80a7fd8",
                            "From Self-XSS to Persistent XSS on Login Portal": "https://medium.com/@nnez/always-escalate-from-self-xss-to-persistent-xss-on-login-portal-54265b0adfd0",
                            "Self XSS to Account Takeover": "https://medium.com/@Ch3ckM4te/self-xss-to-account-takeover-72c89775cf8f",
                            "Blind Xss (A mind game to win the battle)": "https://medium.com/@dirtycoder0124/blind-xss-a-mind-game-to-win-the-battle-4fc67c524678?",
                            "BugBounty | A Dom Xss": "https://jinone.github.io/bugbounty-a-dom-xss/",
                            "How I turned Self XSS to Stored via CSRF": "https://medium.com/@abhishekY495/how-i-turned-self-xss-to-stored-via-csrf-d12eaaf59f2e",
                            "XSS will never die": "https://medium.com/@Lekssik/xss-will-never-die-eb3584081a5f",
                            "Cookie-based XSS exploitation": "https://medium.com/@ISecMax/cookie-based-xss-exploitation-2300-bug-bounty-story-9bc532ffa564",
                            "Self XSS To Evil XSS": "https://saadahmedx.medium.com/self-xss-to-evil-xss-bcf2494a82a4",
                            "CSRF Attack can lead to Stored XSS": "https://infosecwriteups.com/csrf-attack-can-lead-to-stored-xss-f40ba91f1e4f",
                            "The 5000$ Google XSS": "https://blog.it-securityguard.com/bugbounty-the-5000-google-xss/",
                            "XSS by Tossing Cookies": "https://wesecureapp.com/blog/xss-by-tossing-cookies/",
                            "Medium Content Spoofing Leads to XSS": "https://ahussam.me/Medium-content-spoofing-xss/",
                            "3 Minutes & XSS!": "https://infosecwriteups.com/3-minutes-xss-71e3340ad66b",
                            "The 2.5 BTC Stored XSS": "https://medium.com/@khaled.hassan/the-2-5-btc-stored-xss-f2f9393417f2",
                        },
                        "XSS",
                    )
                else:
                    break

        elif vulns == "1":
            os.system("clear")
            banner.main()
            banner.attack("XXE - XML External Entity")
            # name,command,discription,writeups,link="",method="kali",github_install="",github_check=""
            github = "No tools available for this Vulnerability type.\nIt is recommended to test manually for XML External Entity (XXE) to get better understanding & results.\nCheck out the writeup section to to learn about XXE"
            template.template(
                "XXE",
                "no-tools",
                github.strip(),
                {
                    "XXE": "https://phonexicum.github.io/infosec/xxe.html",
                    "XML External Entity Injection Processing (Intigriti)": "https://blog.intigriti.com/hackademy/xml-external-entity-processing-xxe/",
                    "XML external entity (XXE) injection": "https://portswigger.net/web-security/xxe",
                    "Exploitation: XXE Injection": "https://depthsecurity.com/blog/exploitation-xml-external-entity-xxe-injection",
                    "XML External Entity Injection Processing (OWASP)": "https://owasp.org/www-community/vulnerabilities/XML_External_Entity_(XXE)_Processing",
                    "XML External Entity Prevention Cheat Sheet": "https://cheatsheetseries.owasp.org/cheatsheets/XML_External_Entity_Prevention_Cheat_Sheet.html",
                    "Testing for XML Injection": "https://wiki.owasp.org/index.php/Testing_for_XML_Injection_(OTG-INPVAL-008)",
                    "XXE Injection Payload List": "https://github.com/payloadbox/xxe-injection-payload-list",
                },
            )

        elif vulns == "2":
            os.system("clear")
            banner.main()
            banner.attack("HTML Injection")
            # name,command,discription,writeups,link="",method="kali",github_install="",github_check=""
            github = "No tools available for this Vulnerability type.\nIt is recommended to test manually for HTML Injection to get better understanding & results.\nCheck out the writeup section to to learn about HTML Injection"
            template.template(
                "HTML Injection",
                "no-tools",
                github.strip(),
                {
                    "Comprehensive Guide on HTML Injection": "https://www.hackingarticles.in/comprehensive-guide-on-html-injection/",
                    "HTML Injection(Unique Exploitation)": "https://medium.com/@pratiky054/html-injection-unique-exploitation-a5c3d4e6fed8",
                    "Better Exfiltration via HTML Injection": "https://d0nut.medium.com/better-exfiltration-via-html-injection-31c72a2dae8b",
                    "HTML injection via email confirmation!": "https://medium.com/cyberverse/got-easiest-bounty-with-html-injection-via-email-confirmation-b1b10575a105",
                    "HTML Injection Tutorial": "https://www.softwaretestinghelp.com/html-injection-tutorial/",
                },
            )

        elif vulns == "3":
            while True:
                os.system("clear")
                banner.main()
                banner.attack("SQL Injection")
                # name,command,discription,writeups,link="",method="kali",github_install="",github_check=""
                ask = vuln_options()
                if ask == "1":
                    while True:
                        os.system("clear")
                        banner.main()
                        banner.attack("SQL Injection")
                        des = "It is recommended to test manually for SQL Injection to get better understanding & results.\nCheck out the writeup section to to learn about SQL Injection"
                        banner.description(des)
                        list_tools = ["SqlMap", "go back"]
                        for i in range(len(list_tools)):
                            print(
                                colors.options,
                                f"{i}) {list_tools[i]}".title(),
                                colors.reset,
                            )
                        option = input(
                            f"\n {colors.select}Select an Option ->{colors.reset} "
                        )
                        if option == "0":
                            print("\n[+] SQLMap")
                            github = github_getting_text("https://sqlmap.org/", "p", 0)
                            template.template(
                                "sqlmap",
                                "sqlmap -h",
                                github.strip(),
                                {
                                    "What is SQL Injection? How to do it with sqlmap?": "https://medium.com/@feat7/what-is-sql-injection-how-to-do-it-with-sqlmap-1e630e8220b7",
                                    "SQL injection using Sqlmap": "https://auntoracharja.medium.com/sql-injection-using-sqlmap-44aa84f7779",
                                    "SQLmap Full Guide For Beginners": "https://systemweakness.com/sqlmap-full-guide-for-beginners-920934cdedac",
                                    "How to use SQLMAP to test a website for SQL Injection vulnerability": "https://www.geeksforgeeks.org/use-sqlmap-test-website-sql-injection-vulnerability/",
                                    "SQLMap - Cheetsheat": "https://book.hacktricks.xyz/pentesting-web/sql-injection/sqlmap",
                                    "TryHackMe : SQLMAP Writeup": "https://nareshlamgade.com.np/2021/05/tryhackme-sqlmap-writeup/",
                                    "Sqlmap - InfoSec": "https://infosecwriteups.com/tagged/sqlmap",
                                },
                            )
                        else:
                            # print(f"{colors.red}[-]Wrong Input{colors.reset}")
                            break
                elif ask == "2":
                    writeup.writeup(
                        {
                            "SQL Injection Cheatsheet": "https://www.invicti.com/blog/web-security/sql-injection-cheat-sheet/",
                            "SQL Injection payload lits": "https://infosecwriteups.com/sql-injection-payload-list-b97656cfd66b",
                            "Admin Panel Accessed Via SQL Injection": "https://medium.com/@ratnadip1998/admin-panel-accessed-via-sql-injection-ezy-boooom-57dc60c2815f",
                            "SQL Injection & Remote Code Execution": "https://shahjerry33.medium.com/sql-injection-remote-code-execution-double-p1-6038ca88a2ec",
                            "Double quote Injection (Exploiting SQL Injection)": "https://medium.com/sud0root/bug-bounty-writeups-exploiting-sql-injection-vulnerability-20b019553716",
                            "Hey WAF! Better Luck Next Time! ": "https://akashroxstarz.medium.com/hey-waf-better-luck-next-time-a1df7f444863",
                            "Blind (time-based) SQLi": "https://jspin.re/fileupload-blind-sqli/",
                            "Exploiting “Google BigQuery” SQLI Vulnerability": "https://hackemall.live/index.php/2020/03/31/akamai-web-application-firewall-bypass-journey-exploiting-google-bigquery-sql-injection-vulnerability/",
                        },
                        "SQL Injection",
                    )
                else:
                    break

        elif vulns == "4":
            while True:
                os.system("clear")
                banner.main()
                banner.attack("Command Injection")
                # name,command,discription,writeups,link="",method="kali",github_install="",github_check=""
                ask = vuln_options()
                if ask == "1":
                    while True:
                        os.system("clear")
                        banner.main()
                        banner.attack("Command Injection")
                        des = "It is recommended to test manually for Command Injection to get better understanding & results.\nCheck out the writeup section to to learn about Command Injection"
                        banner.description(des)
                        list_tools = ["Commix", "go back"]
                        for i in range(len(list_tools)):
                            print(
                                colors.options,
                                f"{i}) {list_tools[i]}".title(),
                                colors.reset,
                            )
                        option = input(
                            f"\n {colors.select}Select an Option ->{colors.reset} "
                        )
                        if option == "0":
                            print("\n[+] Commix")
                            github = github_getting_text(
                                "https://github.com/commixproject/commix",
                                "p[dir=auto]",
                                3,
                            )
                            template.template(
                                "commix",
                                "python commix.py -h",
                                github.strip(),
                                {
                                    "Commix-Command Injection Exploiter (Beginner’s Guide)": "https://www.hackingarticles.in/commix-command-injection-exploiter-beginners-guide/",
                                    "Commix – OS Command Injection and Exploitation Tool": "https://www.geeksforgeeks.org/commix-os-command-injection-and-exploitation-tool/",
                                    "Commix - Automate Exploiting Command Injection Flaws in Web Applications": "https://null-byte.wonderhowto.com/how-to/use-commix-automate-exploiting-command-injection-flaws-web-applications-0189044/",
                                    "Commix : Detecting & Exploiting Command Injection Flaws.": "https://www.blackhat.com/docs/eu-15/materials/eu-15-Stasinopoulos-Commix-Detecting-And-Exploiting-Command-Injection-Flaws.pdf",
                                },
                                link="https://github.com/commixproject/commix.git",
                                method="github",
                                github_install="git clone https://github.com/commixproject/commix.git",
                                github_check="commix",
                            )
                        else:
                            # print(f"{colors.red}[-]Wrong Input{colors.reset}")
                            break
                elif ask == "2":
                    writeup.writeup(
                        {
                            "Breaking down — Command Injections": "https://infosecwriteups.com/breaking-down-command-injections-97d1029576",
                            "Command Injection Payload List": "https://github.com/payloadbox/command-injection-payload-list",
                            "Command Injection - PayloadAllTheThings": "https://github.com/swisskyrepo/PayloadsAllTheThings/tree/master/Command%20Injection",
                            "Comprehensive Guide on OS Command Injection": "https://www.hackingarticles.in/comprehensive-guide-on-os-command-injection/",
                            "Command Injection - OWASP": "https://owasp.org/www-community/attacks/Command_Injection",
                        },
                        "Command Injection",
                    )
                else:
                    break

        elif vulns == "5":
            os.system("clear")
            banner.main()
            banner.attack("HTTP Request Smuggling")
            github = "No tools available for this Vulnerability type.\nIt is recommended to test manually for HTTP Req. Smuggling to get better understanding & results.\nCheck out the writeup section to to learn about HTTP Req. Smuggling"
            template.template(
                "HTTP Request Smuggling",
                "no-tools",
                github.strip(),
                {
                    "HTTP request smuggling Explained": "https://infosecwriteups.com/http-request-smuggling-explained-and-exploited-part-0x1-89ce2956534f",
                    "HTTP request smuggling": "https://portswigger.net/web-security/request-smuggling",
                    "HTTP Request Smuggling - Cheat Sheet": "https://0xn3va.gitbook.io/cheat-sheets/web-application/http-request-smuggling",
                    "Write up of two HTTP Requests Smuggling": "https://medium.com/@cc1h2e1/write-up-of-two-http-requests-smuggling-ff211656fe7d",
                    "HTTP Request Smuggling - HackTricks": "https://book.hacktricks.xyz/pentesting-web/http-request-smuggling",
                },
            )

        elif vulns == "6":
            os.system("clear")
            banner.main()
            banner.attack("HTTP Parameter Pollution")
            github = "No tools available for this Vulnerability type.\nIt is recommended to test manually for HTTP Parameter Pollution to get better understanding & results.\nCheck out the writeup section to to learn about HTTP Parameter Pollution"
            template.template(
                "HTTP Parameter Pollution",
                "no-tools",
                github.strip(),
                {
                    "Behind the Scene : HTTP Parameter Pollution": "https://infosecwriteups.com/behind-the-scene-http-parameter-pollution-534b4fa2449c",
                    "Testing for HTTP Parameter Pollution": "https://owasp.org/www-project-web-security-testing-guide/latest/4-Web_Application_Security_Testing/07-Input_Validation_Testing/04-Testing_for_HTTP_Parameter_Pollution",
                    "HTTP Parameter Pollution - HackTricks": "https://book.hacktricks.xyz/pentesting-web/parameter-pollution",
                    "HTTP Parameter Pollution - Intigiti": "https://blog.intigriti.com/hackademy/http-parameter-pollution/",
                    "Client-side HTTP parameter pollution": "https://portswigger.net/kb/issues/00501400_client-side-http-parameter-pollution-reflected",
                },
            )

        elif vulns == "7":
            while True:
                os.system("clear")
                banner.main()
                banner.attack("Open Redirection")
                # name,command,discription,writeups,link="",method="kali",github_install="",github_check=""
                ask = vuln_options()
                if ask == "1":
                    while True:
                        os.system("clear")
                        banner.main()
                        banner.attack("Open Redirection")
                        des = "It is recommended to test manually for Open Redirection to get better understanding & results.\nCheck out the writeup section to to learn about Open Redirection"
                        banner.description(des)
                        list_tools = ["OpenRedireX", "Oralyzer", "go back"]
                        for i in range(len(list_tools)):
                            print(
                                colors.options,
                                f"{i}) {list_tools[i]}".title(),
                                colors.reset,
                            )
                        option = input(
                            f"\n {colors.select}Select an Option ->{colors.reset} "
                        )
                        if option == "0":
                            print("\n[+] OpenRedireX")
                            github = github_getting_text(
                                "https://github.com/devanshbatham/OpenRedireX",
                                "ul[dir=auto]",
                                0,
                            )
                            template.template(
                                "OpenRedireX",
                                "python3 openredirex.py -h",
                                github.strip(),
                                {
                                    "OpenRedireX – Open Redirection Vulnerability Finder Tool in Linux": "https://www.geeksforgeeks.org/openredirex-open-redirection-vulnerability-finder-tool-in-linux/",
                                    "OpenRedireX – A Open Redirection Vulnerability Finder": "https://secnhack.in/openredirex-a-open-redirection-vulnerability-finder/",
                                    "Open Redirect Scanner with Uber.com": "https://infosecwriteups.com/open-redirect-scanner-c72cd60d0bf",
                                    "OpenRedireX – Asynchronous Open redirect Fuzzer for Humans": "https://pentesttools.net/openredirex-asynchronous-open-redirect-fuzzer-for-humans/",
                                },
                                link="https://github.com/devanshbatham/OpenRedireX",
                                method="github",
                                github_install="git clone https://github.com/devanshbatham/OpenRedireX.git",
                                github_check="OpenRedireX",
                            )
                        elif option == "1":
                            print("\n[+] Oralyzer")
                            github = github_getting_text(
                                "https://github.com/r0075h3ll/Oralyzer",
                                "p[dir=auto]",
                                0,
                            )
                            template.template(
                                "Oralyzer",
                                "python3 oralyzer.py -h",
                                github.strip(),
                                {
                                    "Oralyzer : Linux Tool To Identify Open Redirection": "https://www.geeksforgeeks.org/oralyzer-linux-tool-to-identify-open-redirection/",
                                    "Oralyzer – A Automatic Open Redirection Vulnerability Finder": "https://secnhack.in/oralyzer-a-automatic-open-redirection-vulnerability-finder/",
                                    "Oralyzer : Tool To Identify Open Redirection": "https://kalilinuxtutorials.com/oralyzer",
                                    "Oralyzer – Tool To Identify Open Redirection": "https://pentesttools.net/oralyzer-tool-to-identify-open-redirection/",
                                },
                                link="https://github.com/r0075h3ll/Oralyzer.git",
                                method="github",
                                github_install="git clone https://github.com/r0075h3ll/Oralyzer.git",
                                github_check="Oralyzer",
                            )
                        else:
                            # print(f"{colors.red}[-]Wrong Input{colors.reset}")
                            break
                elif ask == "2":
                    writeup.writeup(
                        {
                            "Open redirect - Improper validation of front-end provided redirect links": "https://learn.snyk.io/lessons/open-redirect/javascript/",
                            "Open Redirect - Intigriti": "https://blog.intigriti.com/hackademy/open-redirect/",
                            "Top 25 Open Redirect Bug Bounty Reports": "https://corneacristian.medium.com/top-25-open-redirect-bug-bounty-reports-5ffe11788794",
                            "Open Redirect Payload List": "https://github.com/payloadbox/open-redirect-payload-list",
                            "Open Redirect PayloadAllThethings": "https://github.com/swisskyrepo/PayloadsAllTheThings/tree/master/Open%20Redirect",
                            "Open-redirection leads to a bounty": "https://infosecwriteups.com/open-redirection-leads-to-a-bounty-d94029e11d17",
                            "Strange Redirect (Fixed but no bounty)": "https://medium.com/@abhishekY495/strange-redirect-fixed-but-no-bounty-54425aea7f19",
                            "Open Redirect To XSS on Login Page": "https://nassimchami.medium.com/1st-bug-bounty-writeup-open-redirect-to-xss-on-login-page-313221da2879",
                        },
                        "Open Redirection",
                    )
                else:
                    break

        elif vulns == "8":
            os.system("clear")
            banner.main()
            banner.attack("LFI - Local File Inclusion")
            github = "No tools available for this Vulnerability type.\nIt is recommended to test manually for LFI to get better understanding & results.\nCheck out the writeup section to to learn about Local File Inclusion"
            template.template(
                "LFI",
                "no-tools",
                github.strip(),
                {
                    "LFI Attack Examples": "https://brightsec.com/blog/lfi-attack-real-life-attacks-and-attack-examples/",
                    "What is Local File Inclusion (LFI)?": "https://www.acunetix.com/blog/articles/local-file-inclusion-lfi/",
                    "Testing for Local File Inclusion": "https://wiki.owasp.org/index.php/Testing_for_Local_File_Inclusion",
                    "CVV #1: Local File Inclusion": "https://infosecwriteups.com/cvv-1-local-file-inclusion-ebc48e0e479a",
                },
            )

        else:
            return


def vuln_options():
    print(f"{colors.options}1) Tools")
    print(f"2) Write-ups")
    print(f"3) Go Back")
    try:
        ask = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
    except KeyboardInterrupt:
        template.exit_program()
    return ask


def github_getting_text(link, selector, indexvalue):
    print("Please Wait....\r", end="")
    URL = link
    try:
        r = requests.get(URL)
        soup = BeautifulSoup(r.content, "html.parser")
        paras = soup.select(selector)
        # check index value from test file
        return paras[indexvalue].text
    except:
        return f"{colors.red}Not Loaded Because No Internet Connection{colors.reset}"


if __name__ == "__main__":
    main()
